| Title: | Translate everything into Banana size. |
|---|---|
| Description: | Translate everything into bananas. |
| Authors: | Roel M. Hogervorst [aut, cre] (ORCID: <https://orcid.org/0000-0001-7509-0328>) |
| Maintainer: | Roel M. Hogervorst <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-19 10:28:13 UTC |
| Source: | https://github.com/RMHogervorst/banana |
This creates a double vector that represents banana so when it is printed, it is converted and displayed as 🍌. However the underlying structure is still units vector.
banana(x = double()) is_banana(x) as_banana(x)banana(x = double()) is_banana(x) as_banana(x)
x |
object to convert into banana |
An S3 vector of class 'banana'.
banana(c(0.25, 0.5, 0.75))banana(c(0.25, 0.5, 0.75))
Find the best fitting banana
best_banana_fit(numeric_vector)best_banana_fit(numeric_vector)